"use strict";
/**
 * Config
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.setConfigFilter = exports.setConfig = exports.config = void 0;
const filters_js_1 = require("../utils/filters/filters.js");
/**
 * Default options
 *
 * @type {Config}
 */
let config = {
    namespace: 'ssf',
    source: 'static',
    title: 'Static Site',
    meta: {
        description: '',
        image: ''
    },
    partialTypes: [
        'navigation',
        'navigationItem',
        'redirect'
    ],
    wholeTypes: [
        'page'
    ],
    archiveMeta: {},
    normalTypes: {},
    renderTypes: {},
    renderFunctions: {},
    renderLayout: async () => { return ''; },
    renderHttpError: undefined,
    renderNavigations: undefined,
    ajaxFunctions: {},
    actions: {},
    filters: {},
    shortcodes: {},
    image: {
        url: '/assets/img/',
        quality: 75,
        sizes: [
            200, 400, 600, 800, 1000, 1200, 1600, 2000
        ]
    },
    parents: {},
    navigation: [],
    navigationItem: [],
    scriptMeta: {},
    formMeta: {},
    env: {
        dev: true,
        prod: false,
        build: false,
        cache: false,
        dir: '',
        urls: {
            dev: '/',
            prod: ''
        }
    },
    store: {
        dir: 'lib/store',
        files: {
            slugs: {
                data: '',
                name: 'slugs.json'
            },
            parents: {
                data: '',
                name: 'parents.json'
            },
            navigations: {
                data: '',
                name: 'navigations.json'
            },
            navigationItems: {
                data: '',
                name: 'navigation-items.json'
            },
            archiveMeta: {
                data: '',
                name: 'archive-meta.json'
            },
            formMeta: {
                data: '',
                name: 'form-meta.json'
            }
        }
    },
    serverless: {
        dir: 'functions',
        files: {
            ajax: 'ajax/index.js',
            preview: '',
            reload: ''
        },
        routes: {
            reload: []
        }
    },
    redirects: {
        file: 'site/_redirects',
        data: []
    },
    cms: {
        name: '',
        space: '',
        prodUser: '',
        prodCredential: '',
        prodHost: '',
        devUser: '',
        devCredential: '',
        devHost: ''
    },
    static: {
        dir: 'json',
        image: {
            inputDir: 'src/assets/img',
            outputDir: 'site/assets/img',
            dataFile: 'lib/store/image-data.json'
        }
    },
    styles: {
        inputDir: 'src',
        outputDir: 'css',
        deps: new Map(),
        build: new Map()
    },
    scripts: {
        inputDir: 'lib',
        outputDir: 'js',
        deps: new Map(),
        build: new Map()
    },
    apiKeys: {
        smtp2go: ''
    }
};
exports.config = config;
/**
 * Update default config with user options
 *
 * @type {ConfigSet}
 */
const setConfig = (args) => {
    exports.config = config = Object.assign(config, args);
    if (config.filter !== undefined) {
        (0, filters_js_1.addFilter)('config', config.filter);
    }
    return config;
};
exports.setConfig = setConfig;
/**
 * Update config based on env variables
 *
 * @type {ConfigSetFilter}
 */
const setConfigFilter = async (env) => {
    exports.config = config = await (0, filters_js_1.applyFilters)('config', config, env);
};
exports.setConfigFilter = setConfigFilter;
