"use strict";
/**
 * Serverless - Preview
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Preview = void 0;
const config_js_1 = require("../../config/config.js");
const contentfulData_js_1 = require("../../utils/contentful/contentfulData.js");
const object_js_1 = require("../../utils/object/object.js");
const string_js_1 = require("../../utils/string/string.js");
const filters_js_1 = require("../../utils/filters/filters.js");
const actions_js_1 = require("../../utils/actions/actions.js");
const shortcodes_js_1 = require("../../utils/shortcodes/shortcodes.js");
const path_js_1 = require("../../utils/path/path.js");
const render_js_1 = require("../../render/render.js");
/**
 * Output preview from contentful
 *
 * @param {PreviewArgs} args
 * @return {Promise<Response>} Response
 */
const Preview = async ({ request, functionPath, next, env, siteConfig }) => {
    /* Params */
    const { searchParams } = new URL(request.url);
    const contentType = searchParams.get('content_type');
    const id = searchParams.get('preview');
    /* Preview id and content type required */
    if (!(0, string_js_1.isStringStrict)(id) || !(0, string_js_1.isStringStrict)(contentType)) {
        return next();
    }
    /* Config */
    (0, config_js_1.setConfig)(siteConfig);
    await (0, config_js_1.setConfigFilter)(env);
    siteConfig.env.dir = (0, path_js_1.getPathDepth)(functionPath);
    (0, filters_js_1.setFilters)(siteConfig.filters);
    (0, actions_js_1.setActions)(siteConfig.actions);
    (0, shortcodes_js_1.setShortcodes)(siteConfig.shortcodes);
    /* Data params */
    const previewData = { id, contentType };
    /* Output */
    const data = await (0, render_js_1.render)({
        previewData,
        allData: await (0, contentfulData_js_1.getAllContentfulData)({
            previewData
        })
    });
    let html = '';
    if ((0, object_js_1.isObjectStrict)(data)) {
        html = data.output !== undefined ? data.output : '';
    }
    return new Response(html, {
        status: 200,
        headers: {
            'Content-Type': 'text/html;charset=UTF-8'
        }
    });
};
exports.Preview = Preview;
