/**
 * Utils - Filters
 */
import type { Filters, FiltersFunctions } from './filtersTypes.js';
/**
 * Store filter callbacks by name
 *
 * @type {FiltersFunctions}
 */
declare let filters: FiltersFunctions;
/**
 * Add filter to filters object
 *
 * @param {string} name
 * @param {function} filter
 * @return {boolean}
 */
declare const addFilter: <T extends keyof Filters>(name: T, filter: Filters[T]) => boolean;
/**
 * Remove filter from filters object
 *
 * @param {string} name
 * @param {function} filter
 * @return {boolean}
 */
declare const removeFilter: <T extends keyof Filters>(name: T, filter: Filters[T]) => boolean;
/**
 * Update value from callback return values
 *
 * @param {string} name
 * @param {*} value
 * @param {*} [args]
 * @return {Promise<*>}
 */
declare const applyFilters: <T, U>(name: string, value: T, args?: U) => Promise<T>;
/**
 * Empty filters object
 *
 * @return {void}
 */
declare const resetFilters: () => void;
/**
 * Fill filters object
 *
 * @param {Filters} args
 * @return {boolean}
 */
declare const setFilters: (args: Partial<Filters>) => boolean;
export { filters, addFilter, removeFilter, applyFilters, resetFilters, setFilters };
